<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

$App->setSession('QueryResult',$QueryResult);
$App->setSession('SimpleQuery',$SimpleQuery);
$App->setSession('ExtQuery',$ExtQuery);
$App->setSession('Backend',$Backend);
$App->setSession('EMail',$EMail);

$App->setSession('search_limit',$search_limit);
$App->setSession('timeslice',$timeslice);
$App->setSession('sortOrder',$sortOrder);

$App->assign('QueryList',$QueryList);
$App->assign('QueryResult',$QueryResult);
$App->assign('SimpleQuery',$SimpleQuery);
$App->assign('ExtQuery',$ExtQuery);
if ($QueryResult) {
    $App->assign('MailList',$QueryResult->fetchMails());
}
try {
    if ($EMail) { // EMail object may not be defined
        $App->assign('EMail',$EMail);
        $EMailBody = $EMail->getBody('text/plain');
        $App->assign('EMailBody',$EMailBody);
        $App->assign('EMailBodyTemplate','showContentText.tpl');
    }
}
catch (Exception $e) {
    $ExceptionMessage = $e->getMessage();
    if ($ExceptionMessage == 'CONTENT_HTML') {
        $App->assign('EMailBodyTemplate','showContentHtml.tpl');
    }
    else {
        $App->assign('EMailBodyTemplate','showContentUnknown.tpl');
    }
}

$App->assign('search_limit',$search_limit);
$App->assign('timeslice',$timeslice);

$App->assign('sortOrder',$sortOrder);

if (isset($displayedMailId))
    $App->assign('displayedMailId',$displayedMailId);

if (isset($queryId)) // display current stored query
    $App->assign('queryId',$queryId);


?>
